@@ -16,13 +16,18 @@ if (!requireNamespace("yaml", quietly = TRUE)) {
     Sys.setenv("DATAVERSE_SERVER" = config$server)
     Sys.setenv("DATAVERSE_KEY"    = config$api_token)
 
-    if (as.Date(config$api_token_expiration) < Sys.Date()) {
-      stop(
-        "The API token expired on `",
-        config$api_token_expiration,
-        "`, so the tests would probably fail.  ",
-        "Please regenerate a new token and update `inst/constants.yml`"
-      )
+    # To better identify the source of problems, check if the token is expired.
+    #   This check *should* be unnecessary on CRAN, since not CRAN tests should
+    #   try to access any server.
+    if (Sys.getenv("NOT_CRAN") %in% c("", "true")) {
+      if (as.Date(config$api_token_expiration) < Sys.Date()) {
+        stop(
+          "The API token expired on `",
+          config$api_token_expiration,
+          "`, so the tests would probably fail.  ",
+          "Please regenerate a new token and update `inst/constants.yml`"
+        )
+      }
     }
     rm(config)
   }
