@@ -1,10 +1,9 @@
-context("Data Access API")
-
 # See https://demo.dataverse.org/dataverse/dataverse-client-r
 # https://doi.org/10.70122/FK2/HXJVJU
 
 test_that("get file metadata from DOI and filename", {
-  testthat::skip_if_offline("demo.dataverse.org")
+  # testthat::skip_if_offline("demo.dataverse.org")
+  testthat::skip_on_cran()
   actual <- get_file_metadata(
     file    = "roster-bulls-1996.tab",
     dataset = "doi:10.70122/FK2/HXJVJU"
@@ -14,7 +13,8 @@ test_that("get file metadata from DOI and filename", {
 })
 
 test_that("get file metadata from file id", {
-  testthat::skip_if_offline("demo.dataverse.org")
+  # testthat::skip_if_offline("demo.dataverse.org")
+  testthat::skip_on_cran()
   actual <- get_file_metadata(
     file = 1734005
   )
